@@ -140,7 +140,9 @@ TEMPLATE_TEST_CASE( "uniform_integer_distribution can handle unit ranges",
                     uint32_t,
                     int32_t,
                     uint64_t,
-                    int64_t ) {
+                    int64_t,
+                    size_t,
+                    ptrdiff_t) {
     // We want random seed to sample different parts of the rng state,
     // the output is predetermined anyway
     std::random_device rd;
@@ -149,7 +151,7 @@ TEMPLATE_TEST_CASE( "uniform_integer_distribution can handle unit ranges",
     Catch::SimplePcg32 pcg( seed );
 
     // We check unitary ranges of 3 different values, min for type, max for type,
-    // some value inbetween just to make sure
+    // some value in between just to make sure
     SECTION("lowest value") {
         constexpr auto lowest = std::numeric_limits<TestType>::min();
         Catch::uniform_integer_distribution<TestType> dist( lowest, lowest );
@@ -178,7 +180,7 @@ TEST_CASE( "uniform_integer_distribution can handle boolean unit ranges",
     Catch::SimplePcg32 pcg( seed );
 
     // We check unitary ranges of 3 different values, min for type, max for
-    // type, some value inbetween just to make sure
+    // type, some value in between just to make sure
     SECTION( "lowest value" ) {
         Catch::uniform_integer_distribution<bool> dist( false, false );
         CheckReturnValue( dist, pcg, false );
@@ -493,6 +495,21 @@ TEMPLATE_TEST_CASE( "uniform_integer_distribution is reproducible",
     REQUIRE_THAT(generated, Catch::Matchers::RangeEquals(uniform_integer_test_params<TestType>::expected));
 }
 
+// The reproducibility tests assume that operations on `float`/`double`
+// happen in the same precision as the operated-upon type. This is
+// generally true, unless the code is compiled for 32 bit targets without
+// SSE2 enabled, in which case the operations are done in the x87 FPU,
+// which usually implies doing math in 80 bit floats, and then rounding
+// into smaller type when the type is saved into memory. This obviously
+// leads to a different answer, than doing the math in the correct precision.
+#if ( defined( _MSC_VER ) && _M_IX86_FP < 2 ) ||              \
+    ( defined( __GNUC__ ) &&                                  \
+      ( ( defined( __i386__ ) || defined( __x86_64__ ) ) ) && \
+      !defined( __SSE2_MATH__ ) )
+#    define CATCH_TEST_CONFIG_DISABLE_FLOAT_REPRODUCIBILITY_TESTS
+#endif
+
+#if !defined( CATCH_TEST_CONFIG_DISABLE_FLOAT_REPRODUCIBILITY_TESTS )
 
 namespace {
     template <typename T>
@@ -570,6 +587,8 @@ TEMPLATE_TEST_CASE( "uniform_floating_point_distribution is reproducible",
     REQUIRE_THAT( generated, Catch::Matchers::RangeEquals( uniform_fp_test_params<TestType>::expected ) );
 }
 
+#endif // ^^ float reproducibility tests are enabled
+
 TEMPLATE_TEST_CASE( "uniform_floating_point_distribution can handle unitary ranges",
                     "[rng][distribution][floating-point][approvals]",
                     float,
@@ -579,7 +598,7 @@ TEMPLATE_TEST_CASE( "uniform_floating_point_distribution can handle unitary rang
     CAPTURE( seed );
     Catch::SimplePcg32 pcg( seed );
 
-    const auto highest = uniform_fp_test_params<TestType>::highest;
+    const auto highest = TestType(385.125);
     Catch::uniform_floating_point_distribution<TestType> dist( highest,
                                                                highest );
 
